/// <reference types="react" />
import { PropsWithMetadata } from '@highlight-ui/utils-commons';
import { InputProps } from '@highlight-ui/input';
import flatpickr from 'flatpickr';
export declare type DateRange = [Date | undefined, Date | undefined];
export declare type CalendarProps = PropsWithMetadata<{
    value?: Date | Date[] | null;
    mode?: flatpickr.Options.Options['mode'];
    onChange: (date: Date[], asString: string) => void;
    isOpened: boolean;
    onClickOutside?: (clickTarget: Node) => void;
    style?: React.CSSProperties;
    disabledDates?: Date[];
    minDate?: Date;
    maxDate?: Date;
}>;
declare type InputPickerProps = Omit<InputProps, 'onChange' | 'value' | 'maskOptions' | 'onMaskAccept' | 'onMaskComplete' | 'prefix' | 'prefixVariant' | 'suffix' | 'autoComplete'>;
export declare type DateInputProps = InputPickerProps & PropsWithMetadata<{
    /** Allows parsing and entering time of date, format is based on locale */
    mode: 'time' | 'date';
    /** Minimum inclusive allowed date */
    minDate?: Date;
    /** Maximum inclusive allowed date */
    maxDate?: Date;
    /** Specify whether to show an icon or not */
    withIcon?: boolean;
    /** List of the dates which are not allowed for selection */
    disabledDates?: Date[];
    /** The callback being fired on each change on the input or when a date from the calendar is selected */
    onChange?: (date: undefined | Date, inputValue: string) => void;
    /** The controlled value of the input */
    value?: Date | null;
}>;
export declare type DatePickerProps = Omit<DateInputProps, 'onChange' | 'mode' | 'withIcon'> & {
    /** Allows providing a custom class name to the DIV element that surrounds the text */
    className?: string;
    /** The callback being fired on each change on the input or when a date from the calendar is selected */
    onChange?: (date?: Date, inputValue?: string) => void;
    /** Should the calendar close after each selection? */
    closeOnSelect?: boolean;
    /** Should it show the calendar element when the input has focus? */
    noCalendar?: boolean;
};
export declare type RangeDatePickerProps = Omit<DateInputProps, 'onChange' | 'mode' | 'id' | 'value' | 'withIcon'> & {
    /** Allows providing a custom class name to the DIV element that surrounds the text */
    className?: string;
    /** The controlled value of the input */
    range?: DateRange;
    /** The callback being fired on each change on the inputs or when a range of dates from the calendar are selected */
    onChange?: (dates: DateRange, inputValues: [string, string]) => void;
    /** Should the calendar close after each selection? */
    closeOnSelect?: boolean;
    /** This value will be passed as id for the start range input */
    startInputId?: string;
    /** This value will be passed as id for the end range input */
    endInputId?: string;
};
declare type TimePickerInputProps = Omit<InputProps, 'onChange' | 'value' | 'onMaskAccept' | 'onMaskComplete' | 'prefix' | 'prefixVariant' | 'suffix' | 'autoComplete' | 'defaultValue' | 'min' | 'max' | 'step'> & {
    /** Allows providing a custom class name to the DIV element that surrounds the text */
    className?: string;
};
export declare type TimeInputProps = TimePickerInputProps & PropsWithMetadata<{
    /** The callback being fired on each change on the input or when a preset time is selected */
    onChange?: (inputValue: string) => void;
    /** The controlled value of the input */
    value?: string;
    /** What kind of icon to use from FontAwesome collection */
    iconName: string;
    /** `onBLur` event handler */
    onBlur?: (e: React.FocusEvent) => void;
}>;
export declare type ControlledTimePickerProps = TimePickerInputProps & PropsWithMetadata<{
    /** Day that should be returned in the `onChange` handler along with the time */
    day?: Date;
    /** The callback being fired on each change on the input or when a preset time is selected */
    onChange?: (date?: Date, inputValue?: string) => void;
    /** An array of time options from which the user can choose */
    presetTimes?: Date[];
    /** The controlled value of the input */
    value?: Date;
}>;
export declare type TimePickerProps = ControlledTimePickerProps & {
    /** If `defaultValue` is `Date` or `null` TimePicker act as uncontrolled ignoring `value` prop */
    defaultValue?: Date | null;
};
export {};
